==> kmymoney_5.2.1.orig.tar.xz: kmymoney-5.2.1/kmymoney/plugins/views/onlinejoboutbox/onlinejoboutboxview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian Dávid",
                "Name[ca@valencia]": "Christian Dávid",
                "Name[ca]": "Christian Dávid",
                "Name[cs]": "Christian Dávid",
                "Name[de]": "Christian Dávid",
                "Name[en_GB]": "Christian Dávid",
                "Name[eo]": "Christian Dávid",
                "Name[es]": "Christian Dávid",
                "Name[et]": "Christian Dávid",
                "Name[eu]": "Christian Dávid",
                "Name[fi]": "Christian Dávid",
                "Name[fr]": "Christian Dávid",
                "Name[gl]": "Christian Dávid",
                "Name[ia]": "Christian Dávid",
                "Name[it]": "Christian Dávid",
                "Name[ka]": "Christian Dávid",
                "Name[ko]": "Christian Dávid",
                "Name[nb]": "Christian Dávid",
                "Name[nl]": "Christian Dávid",
                "Name[pl]": "Christian Dávid",
                "Name[pt]": "Christian Dávid",
                "Name[pt_BR]": "Christian Dávid",
                "Name[ru]": "Christian Dávid",
                "Name[sk]": "Christian Dávid",
                "Name[sl]": "Christian Dávid",
                "Name[sv]": "Christian Dávid",
                "Name[tr]": "Christian Dávid",
                "Name[uk]": "Christian Dávid",
                "Name[x-test]": "xxChristian Dávidxx",
                "Name[zh_CN]": "Christian Dávid",
                "Name[zh_TW]": "Christian Dávid"
            }
        ],
        "Description": "Adds online job outbox view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista de la safata d'eixida dels treballs en línia a KMyMoney",
        "Description[ca]": "Afegeix la vista de la safata de sortida dels treballs en línia al KMyMoney",
        "Description[en_GB]": "Adds online job outbox view to KMyMoney",
        "Description[eo]": "Aldonas interretan labor-elirkeston vidon al KMyMoney",
        "Description[es]": "Añade la vista de la bandeja de salida de trabajos en línea a KMyMoney",
        "Description[et]": "KMyMoney võrgutöö väljundkasti vaade",
        "Description[eu]": "Lineako lanen irteera ontziko ikuspegia gehitzen dio KMyMoney-ri",
        "Description[fi]": "Lisää KMyMoneyyn lähtevien verkkotöiden näkymän",
        "Description[fr]": "Ajoute la vue boîte d'envoi des tâches en ligne à KMyMoney",
        "Description[gl]": "Engade unha vista fóra da caixa de traballo por Internet a KMyMoney",
        "Description[it]": "Aggiunge la vista delle operazioni in linea in uscita a KMyMoney",
        "Description[ka]": "KMyMoney-ში გამავალი ქსელური დავალებების ხედის დამატება",
        "Description[ko]": "KMyMoney에 온라인 보낼 작업함 보기 추가",
        "Description[nb]": "Legger til visning av utboks for nettjobb i KMyMoney",
        "Description[nl]": "Voegt online weergave van postvak uit toe aan KMyMoney",
        "Description[pl]": "Dodaje widok skrzynki wyjściowej zadań w sieci do KMyMoney",
        "Description[pt]": "Adiciona a área da caixa de saída das tarefas 'online' ao KMyMoney",
        "Description[pt_BR]": "Adiciona área da caixa de saída das tarefas online",
        "Description[ru]": "Добавляет в KMyMoney представление исходящих сетевых заданий",
        "Description[sl]": "V KMyMoney doda pogled na oddano e-pošto",
        "Description[sv]": "Lägger till utkorgsvy för nätjobb i KMyMoney",
        "Description[tr]": "K Param’a çevrimiçi iş giden kutusu görünümü ekleyin",
        "Description[uk]": "Панель вихідних інтернет-завдань у KMyMoney",
        "Description[x-test]": "xxAdds online job outbox view to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加在线任务发件箱视图",
        "EnabledByDefault": true,
        "Icon": "online-banking",
        "Id": "onlinejoboutboxview",
        "License": "GPL",
        "Name": "Online job outbox view",
        "Name[ca@valencia]": "Vista en línia de la safata d'eixida dels treballs",
        "Name[ca]": "Vista en línia de la safata de sortida dels treballs",
        "Name[en_GB]": "Online job outbox view",
        "Name[eo]": "Vido pri interreta laboro elirkesto",
        "Name[es]": "Vista de la bandeja de salida de trabajos en línea",
        "Name[et]": "Võrgutöö väljundkast",
        "Name[eu]": "Lineako lanen irteera ontziko ikuspegia",
        "Name[fi]": "Lähtevien verkkotöiden näkymä",
        "Name[fr]": "Vue boîte d'envoi des tâches en ligne",
        "Name[gl]": "Vista fóra da caixa de traballo por Internet",
        "Name[it]": "Vista delle operazioni in linea in uscita",
        "Name[ka]": "გამავალი ქსელური დავალებების ხედი",
        "Name[ko]": "온라인 보낼 작업함 보기",
        "Name[nb]": "Visning av utboks for nettjobb",
        "Name[nl]": "Online weergave van postvak uit van job",
        "Name[pl]": "Skrzynka wyjściowa zadań w sieci",
        "Name[pt]": "Caixa de saída das tarefas 'online'",
        "Name[pt_BR]": "Área da caixa de saída das tarefas online",
        "Name[ru]": "Представление исходящих сетевых заданий",
        "Name[sl]": "Pogled na spletne posle",
        "Name[sv]": "Utkorgsvy för nätjobb",
        "Name[tr]": "Çevrimiçi İş Giden Kutusu Görünümü",
        "Name[uk]": "Панель вихідних даних інтернет-завдань",
        "Name[x-test]": "xxOnline job outbox viewxx",
        "Name[zh_CN]": "线上任务发件箱视图",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.2.2.orig.tar.xz: kmymoney-5.2.2/kmymoney/plugins/views/onlinejoboutbox/onlinejoboutboxview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian Dávid",
                "Name[ar]": "كريستيان دافيد",
                "Name[ca@valencia]": "Christian Dávid",
                "Name[ca]": "Christian Dávid",
                "Name[cs]": "Christian Dávid",
                "Name[de]": "Christian Dávid",
                "Name[en_GB]": "Christian Dávid",
                "Name[eo]": "Christian Dávid",
                "Name[es]": "Christian Dávid",
                "Name[et]": "Christian Dávid",
                "Name[eu]": "Christian Dávid",
                "Name[fi]": "Christian Dávid",
                "Name[fr]": "Christian Dávid",
                "Name[gl]": "Christian Dávid",
                "Name[ia]": "Christian Dávid",
                "Name[it]": "Christian Dávid",
                "Name[ka]": "Christian Dávid",
                "Name[ko]": "Christian Dávid",
                "Name[nb]": "Christian Dávid",
                "Name[nl]": "Christian Dávid",
                "Name[pl]": "Christian Dávid",
                "Name[pt]": "Christian Dávid",
                "Name[pt_BR]": "Christian Dávid",
                "Name[ru]": "Christian Dávid",
                "Name[sk]": "Christian Dávid",
                "Name[sl]": "Christian Dávid",
                "Name[sv]": "Christian Dávid",
                "Name[tr]": "Christian Dávid",
                "Name[uk]": "Christian Dávid",
                "Name[zh_CN]": "Christian Dávid",
                "Name[zh_TW]": "Christian Dávid"
            }
        ],
        "Description": "Adds online job outbox view to KMyMoney",
        "Description[ar]": "أضف عرض صندوق صادر المهام عبر الإنترنت إلى «أموالك» أموالك",
        "Description[ca@valencia]": "Afig la vista de la safata d'eixida dels treballs en línia a KMyMoney",
        "Description[ca]": "Afegeix la vista de la safata de sortida dels treballs en línia al KMyMoney",
        "Description[en_GB]": "Adds online job outbox view to KMyMoney",
        "Description[eo]": "Aldonas interretan labor-elirkeston vidon al KMyMoney",
        "Description[es]": "Añade la vista de la bandeja de salida de trabajos en línea a KMyMoney",
        "Description[et]": "KMyMoney võrgutöö väljundkasti vaade",
        "Description[eu]": "Lineako lanen irteera ontziko ikuspegia gehitzen dio KMyMoney-ri",
        "Description[fi]": "Lisää KMyMoneyyn lähtevien verkkotöiden näkymän",
        "Description[fr]": "Ajoute la vue boite d'envoi des tâches en ligne à KMyMoney",
        "Description[gl]": "Engade unha vista fóra da caixa de traballo por Internet a KMyMoney",
        "Description[it]": "Aggiunge la vista delle operazioni in linea in uscita a KMyMoney",
        "Description[ka]": "KMyMoney-ში გამავალი ქსელური დავალებების ხედის დამატება",
        "Description[ko]": "KMyMoney에 온라인 보낼 작업함 보기 추가",
        "Description[nb]": "Legger til visning av utboks for nettjobb i KMyMoney",
        "Description[nl]": "Voegt online weergave van postvak uit toe aan KMyMoney",
        "Description[pl]": "Dodaje widok skrzynki wyjściowej zadań w sieci do KMyMoney",
        "Description[pt]": "Adiciona a área da caixa de saída das tarefas 'online' ao KMyMoney",
        "Description[pt_BR]": "Adiciona área da caixa de saída das tarefas online",
        "Description[ru]": "Добавляет в KMyMoney представление исходящих сетевых заданий",
        "Description[sl]": "V KMyMoney doda pogled na oddano e-pošto",
        "Description[sv]": "Lägger till utkorgsvy för nätjobb i KMyMoney",
        "Description[tr]": "K Param’a çevrimiçi iş giden kutusu görünümü ekleyin",
        "Description[uk]": "Панель вихідних інтернет-завдань у KMyMoney",
        "Description[zh_CN]": "为 KMyMoney 添加在线任务发件箱视图",
        "EnabledByDefault": true,
        "Icon": "online-banking",
        "Id": "onlinejoboutboxview",
        "License": "GPL",
        "Name": "Online job outbox view",
        "Name[ar]": "عرض صندوق صادر المهام عبر الإنترنت",
        "Name[ca@valencia]": "Vista en línia de la safata d'eixida dels treballs",
        "Name[ca]": "Vista en línia de la safata de sortida dels treballs",
        "Name[en_GB]": "Online job outbox view",
        "Name[eo]": "Vido pri interreta laboro elirkesto",
        "Name[es]": "Vista de la bandeja de salida de trabajos en línea",
        "Name[et]": "Võrgutöö väljundkast",
        "Name[eu]": "Lineako lanen irteera ontziko ikuspegia",
        "Name[fi]": "Lähtevien verkkotöiden näkymä",
        "Name[fr]": "Vue boite d'envoi des tâches en ligne",
        "Name[gl]": "Vista fóra da caixa de traballo por Internet",
        "Name[it]": "Vista delle operazioni in linea in uscita",
        "Name[ka]": "გამავალი ქსელური დავალებების ხედი",
        "Name[ko]": "온라인 보낼 작업함 보기",
        "Name[nb]": "Visning av utboks for nettjobb",
        "Name[nl]": "Online weergave van postvak uit van job",
        "Name[pl]": "Skrzynka wyjściowa zadań w sieci",
        "Name[pt]": "Caixa de saída das tarefas 'online'",
        "Name[pt_BR]": "Área da caixa de saída das tarefas online",
        "Name[ru]": "Представление исходящих сетевых заданий",
        "Name[sl]": "Pogled na spletne posle",
        "Name[sv]": "Utkorgsvy för nätjobb",
        "Name[tr]": "Çevrimiçi İş Giden Kutusu Görünümü",
        "Name[uk]": "Панель вихідних даних інтернет-завдань",
        "Name[zh_CN]": "线上任务发件箱视图",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
